
// TreeIterator examples
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

import com.myarch.treeiterator.TreeIterator;
import com.myarch.treeiterator.DOMAdapter;

import org.w3c.dom.Node;

/**
 * Demonstrates the use of the <code>setMaxDepth</code> of the <code>TreeIterator</code>.
 * Traverses only the levels lower than max depth.
 *
 * @author Alexander Ananiev
 */
public class IterMaxDepthTraversal {

  /**
   * Traverses the tree with the traversal depth set to
   * the depth of the "person" level.
   *
   * @param rootNode root of the DOM tree.
   */
  public void traverse ( Node rootNode ) {

    // create iterator
    TreeIterator tIterator = new TreeIterator ( rootNode, new DOMAdapter() );
    // find the depth of the required level
    int targetDepth = -1;
    Node node = null;
    while( (node=(Node)tIterator.next()) != null )
      if (node.getNodeName().equals("person")) {
        targetDepth = tIterator.getDepth();
        break;
      }

    // we can reuse the same iterator
    tIterator.setRoot(rootNode);
    // limit the depth of traversal
    tIterator.setMaxDepth( targetDepth );
    while( (node=(Node)tIterator.next()) != null )  {
      // print node information
      System.out.println( node.getNodeName()+"="+node.getNodeValue());
    }
  }

  public static void main(String[] args) {
    try {
      // default file name
      String filename = "personnel.xml";
      if (args.length == 1)
        // any file can be specified
        filename = args[0];
      new IterMaxDepthTraversal().traverse( ParserUtil.parse( filename ) );
    }
    catch( Exception ex ) {
      ex.printStackTrace();
    }
  }

}
