
// TreeIterator examples
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

import com.myarch.treeiterator.TreeIterator;
import com.myarch.treeiterator.DOMAdapter;

import org.w3c.dom.Node;
import org.w3c.dom.Element;

/**
 * Demonstrates the selecive traversal using <code>skipChildren</code>.
 *
 * @author Alexander Ananiev
 */
public class SelectiveSkipTraversal {

  /**
   * Selectively traverses the tree using <code>skipChildren</code>.
   * Traverses only the branch of "K.Tamura" and ignores other branches.
   *
   * @param rootNode root of the DOM tree.
   */
  public void traverse ( Node rootNode ) {

    // create an iterator.
    int idLevel = 2;
    TreeIterator tIterator = new TreeIterator ( rootNode, new DOMAdapter());
    Node node = null;
    while( ( node=(Node)tIterator.next() )!=null ){
      // print node information
      System.out.println( node.getNodeName()+"="+node.getNodeValue());

      if  ( tIterator.getDepth() == idLevel && ! (node instanceof Element &&
        ((Element)node).getAttribute( "id").equalsIgnoreCase("K.TAMURA" ))) {
        // allow parsing all children of the node -- applies only to the current node
        tIterator.skipChildren();
      }
    }
  }

  public static void main(String[] args) {
    try {
      // default file name
      String filename = "personnel.xml";
      if (args.length == 1)
        // any file can be specified
        filename = args[0];
      new SelectiveSkipTraversal().traverse( ParserUtil.parse( filename ) );
    }
    catch( Exception ex ) {
      ex.printStackTrace();
    }
  }


}
