
// TreeIterator utility
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.


package com.myarch.treeiterator;

import java.util.Iterator;
import java.util.Enumeration;

/**
 * Implements <code>java.util.Iterator</code> interface for <code>Enumeration</code>.
 * Useful when <code>java.util.Iterator</code> interface is not supported directly.
 */
public class EnumerationAdapter implements Iterator {

  private Enumeration enum;

  /**
   * Adapter constructor.
   * @param enum any object implementing Enumeration
   */
  public EnumerationAdapter( Enumeration enum ) {
    this.enum = enum;
  }

 /**
  * Returns the next element in the interation.
  * @return the next element in the iteration
  * @throws NoSuchElementException if no more elements exist.
  */
  public Object next() {
    return enum.nextElement();
  }

 /**
  * Returns true if the iteration has more elements.
  * @return true if the iterator has more elements.
  */
  public boolean hasNext() {
    return enum.hasMoreElements();
  }

   /**
    * This method is defined to comply with <code>Iterator</code> but it is not supported.
    * @throws UnsupportedOperationException whenever it is called
    */
   public void remove() throws UnsupportedOperationException {
     throw new UnsupportedOperationException("Remove is not supported by Enumeration");
   }

}