// TreeIterator utility
// Copyright (c) 2001 Alexander Ananiev & MyArch.com.  All rights reserved.

package com.myarch.treeiterator;

import java.util.Iterator;
import javax.swing.tree.TreeNode;

/**
 * <code>TreeNodeAdapter</code> implementation for
 * <code>javax.swing.tree.TreeNode</code>
 */
public class SwingAdapter implements TreeNodeAdapter {

  /**
   * Returns <code>java.util.Iterator</code> to iterate over children of the node.
   * <br><code>EnumarationAdapter</code> is used since <code>TreeNode</code> doesn't
   * implement the <code>Iterator</code> interface directly.
   *
   * @param node node
   * @return <code>java.util.Iterator</code> for the collection that contains children
   * of the given node.
   */
  public Iterator getChildren( Object node ) {
    return new EnumerationAdapter( ((TreeNode)node).children() );
  }

  /**
   * Returns true if the node has children.
   * @param node node
   * @return <code>true</code> if the node has children
   */
  public boolean hasChildren( Object node ) {
    return ! ((TreeNode)node).isLeaf();
  }
}
